NativeHomeWidgetsWeb class
Web platform stub for native_home_widgets.
Home screen widgets are not supported on the web. All methods throw PlatformNotSupportedException.
- Inheritance
-
- Object
- PlatformInterface
- NativeHomeWidgetsWeb
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearData(
{String? widgetId}) → Future< bool> -
getAllWidgets(
) → Future< List< WidgetInfo> > -
getData(
{required String key, String? widgetId, dynamic defaultValue}) → Future -
getDeepLink(
{required String widgetId}) → Future< String?> -
inherited
-
getPlatformVersion(
) → Future< String?> -
isWidgetInstalled(
String widgetId) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openConfiguration(
) → Future< bool> -
openDeepLink(
{required String widgetId}) → Future< void> -
inherited
-
pinWidget(
) → Future< bool> -
reloadAll(
) → Future< bool> -
removeData(
{required String key, String? widgetId}) → Future< bool> -
saveData(
{required String key, required dynamic value, String? widgetId}) → Future< bool> -
saveDeepLink(
{required String widgetId, required String uri}) → Future< bool> -
inherited
-
setAccessibility(
{required String widgetId, String? label, String? hint, String? value, bool isButton = false, bool isHeader = false}) → Future< bool> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
{String? widgetId}) → Future< bool> -
updateAll(
) → Future< bool>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
dynamic registrar) → void